@@ -60,6 +60,7 @@ ImportImapSettingWizard::ImportImapSettingWizard(QWidget *parent)
     readConfig();
     initializeWizard();
     connect(button(QDialogButtonBox::Help), &QPushButton::clicked, this, &ImportImapSettingWizard::slotHelpClicked);
+    connect(mSearchPage, &ImportImapSettingSearchPage::needToImportSettings, this, &ImportImapSettingWizard::slotNeedToImportSettings);
 }
 
 ImportImapSettingWizard::~ImportImapSettingWizard()
@@ -101,6 +102,12 @@ void ImportImapSettingWizard::initializeWizard()
         setAppropriate(mFinishPageItem, false);
         setCurrentPage(mNoFoundPageItem);
     }
+    nextButton()->setEnabled(false);
+}
+
+void ImportImapSettingWizard::slotNeedToImportSettings(bool b)
+{
+    nextButton()->setEnabled(b);
 }
 
 void ImportImapSettingWizard::next()
